Learn R Programming

gbp (version 0.1.0.4)

Ktlist2d: Ktlist2d

Description

Ktlist2d hold multiple kt for recursive fit

Usage

Ktlist2d

Arguments

Format

An object of class C++Class of length 1.

Details

Ktlist2d hold multiple kt via consider all possible fit onto different xp and different rotation and nlimit

a Ktlist2d class instance has 4 fields:

- n: length of kt candidate position scale vector list

- kt: candidate (x, y, l, d) fit of it current investigating

- xp: candidate extreme point list after kt fit into each corresponding (x, y, l, d) position scale

- s: score of each kt fit: calculate overall extrem point residual space entropy as score, the smaller the better, since smaller entropy indicate concentrated residual space and less number of extreme point.

See Also

Other gbp2d_it: gbp2d_it_create_ktlist