Learn R Programming

gbp (version 0.1.0.4)

Ktlist3d: Ktlist3d

Description

Ktlist3d hold multiple kt for recursive fit

Usage

Ktlist3d

Arguments

Format

An object of class C++Class of length 1.

Details

Ktlist3d hold multiple kt via consider all possible fit onto different xp and different rotation and nlimit

a Ktlist3d class instance has 4 fields:

- n: length of kt candidate position scale vector list

- kt: candidate (x, y, z, l, d, h) fit of it current investigating

- xp: candidate extreme point list after kt fit into each corresponding (x, y, z, l, d, h) position scale

- s: score of each kt fit: calculate overall extrem point residual space entropy as score, the smaller the better, since smaller entropy indicate concentrated residual space and less number of extreme point.

See Also

Other gbp3d_it: gbp3d_it_create_ktlist