Learn R Programming

gbp (version 0.1.0.4)

Ktlist4d: Ktlist4d

Description

Ktlist4d hold multiple kt for recursive fit

Usage

Ktlist4d

Arguments

Format

An object of class C++Class of length 1.

Details

Ktlist4d hold multiple kt via consider all possible fit onto different xp and different rotation and nlimit

a Ktlist4d class instance has 4 fields

- n: length of kt candidate position scale vector list

- kt: candidate (x, y, z, w, l, d, h, w) fit of it current investigating

x, y, z, w - weight holding in bn when fit; l, d, h, w - weight of it itself

- xp: candidate extreme point list after kt fit into each corresponding (x, y, z, l, d, h) position scale

- s: score of each kt fit: calculate overall extrem point residual space entropy as score, the smaller the better, since smaller entropy indicate concentrated residual space and less number of extreme point.

See Also

Other gbp4d_it: gbp4d_it_create_ktlist