Learn R Programming

gbp (version 0.1.0.4)

bppSgl: bppSgl

Description

bpp solution of a single one order or multiple order

Usage

bppSgl

Arguments

Format

An object of class C++Class of length 1.

Details

packing it into multiple bn w.r.t bn size and weight limit while select bn as small as possible

a bppSgl class instance has 6 fields:

- id: order id

list - should sorted or at least grouped w.r.t order id

- it: it position and scale

- x, y, z, w it position and w in the bin (w hold in bn when fit it in bn)

- l, d, h, w it scale along x, y, z and w (w of it itself)

- bn: bn scale

- l, d, h, w bn scale along x, y, z and w

- k: ticket id indicator 0 (if cannot fit into any bin), 1, 2, 3, 4, ...

- kb: ticket bn id indicator - which bn to use for packing each ticket

- ok: ok a quick indicator of any it can not fit into any bn?