bpp_solver_dpp(id, ldhw, m) id order id
it order list
- l, d, h, w it scale along x, y, z and w
it columns should corresponding to id
m a bin list
- l, d, h, w bn scale along x, y, z and w
m should sorted w.r.t preference
and also a list of available bn in data.frame bn - id, l, d, h, w: bn id, length l, depth d, height h, and weight limit w, sorted by peference often smaller prefered,
and a single weight limit wlmt applied on all bin.
bpp solver would solve
select least number of bn for packing each order w.r.t bn size and weight limit and make sure the bn selected are as small as possible.
bpp_solver_dpp_wrapper,
bpp_solver_sgl