Learn R Programming

gbp (version 0.1.0.4)

bpp_solver_dpp_wrapper: bpp_solver_dpp_wrapper

Description

a wrapper over bpp_solver_dpp and expose an nicer r interface

Usage

bpp_solver_dpp_wrapper(it, bn)

Arguments

it

it order itemSKU list

- oid: order id

- sku: stock keeping unit - it id

- l, d, h, w it scale along x, y, z and w

- w will be used as constraint while l, d, h will be used as both constraint and objective

it must be sorted w.r.t oid

bn

bn a bin list

- id: bin id

- l, d, h, w bn scale along x, y, z and w

bn must be sorted w.r.t preference and have l >= d >= h

Value

sn sn solution - it order itemSKU list with tid, bid, and x, y, z - oid: order id inherited from it - tid: ticket id implied one order can be packed using several ticket id each ticket id corresponding to a bid bin id which indicates which bin to use for packing- bid: bin id which bn in bn list should be used in pakcing - sku: stock keeping unit it id - x, y, z it position in the bin - l, d, h it scale along x, y, z l, d, h is not inherited from it as it can be rotated to different orientation for packing- w it weight scale inherited from it

See Also

Other bpp_solver_dpp: bpp_solver_dpp, bpp_solver_sgl