Learn R Programming

gbp (version 0.1.0.4)

bpp_solver_sgl: bpp_solver_sgl

Description

subroutine of bpp_solver_dpp

Usage

bpp_solver_sgl(ldhw, m)

Arguments

ldhw

it order list

- l, d, h, w it scale along x, y, z and w

it columns should corresponding to id

m

m a bin list

- l, d, h, w bn scale along x, y, z and w

m should sorted w.r.t preference

Value

bppSgl

Details

fit a single order into bn list, call gbp4d_solver_dpp_filt() as main solver.

See Also

Other bpp_solver_dpp: bpp_solver_dpp_wrapper, bpp_solver_dpp