Learn R Programming

gbp (version 0.1.0.4)

bpp_viewer_single: bpp_viewer_single

Description

bpp solution viewer on single bin all item

Usage

bpp_viewer_single(it, bn, title = NULL, subtitle = NULL, it_rgl_control = NULL, bn_rgl_control = NULL, label_it = TRUE, label_bn = TRUE)

Arguments

it
it item

- id it id

- x, y, z it position w.r.t bins

- l, d, h it scale along x, y, z

- w it weight

- auto: cc, wd, txt point and lines color, size, legend

bn
bn bins

- id bn id

- l, d, h bn scale

- w bn weight limit

- auto: cc, wd, txt point and lines color, size, legend

title
title
subtitle
subtitle
it_rgl_control
control the color of it in rgl
bn_rgl_control
control the color of bn in rgl
label_it
label text on it corner or not
label_bn
label text on bn corner or not

See Also

Other bpp_viewer: bpp_viewer