gbp1dC++Class of length 1.maximize sum_j=1^n p_j x_j
subject to sum_j=1^n w_j x_j leq c x_j in 0, 1, j = 1, ...., n
and instantiate a gbp1d object with a selectin vector x and an objective z.
gbp1d is implemented as rcpp class, an instantiate can be solved by calling gbp1d_solver_dpp(p, w, c) and gbp1d_solver_min(p, w, c)
gbp1d_solver_dpp