Learn R Programming

gbp (version 0.1.0.4)

gbp2d: gbp2d

Description

generalized bin packing problem in 2 dimension, a.k.a rectangle fill.

Usage

gbp2d

Arguments

Format

An object of class C++Class of length 1.

Details

gbp2d init a profit vector p, a length vector l, a depth vector d, a length constraint ml, and a depth constraint md on l x d rectangle with geometry intepretation.

gbp2d solver would solve

maximize sum_j=1^n p_j k_j

subject to fit (l_j, d_j) at coordinate (x_j, y_j) such that no overlap in ml x md, j = 1, ...., n

and instantiate a gbp2d object with a x-axis coordinate vector x, a y-axis coordinate vector y, a selection vector k, and an objective o.

a gbp2d class instance has 6 fields:

- p: profit of it fit into bn

created via cluster max(l, d) and min(l, d) via gbp2d_solver_dpp_prep_create_p()

- it: it position and scale

- x, y it position in the bin

- l, d it scale along x and y

- bn: bn scale

- l, d bn scale along x and y

- k: selection indicator 0, 1

- o: objective achivement volumn fit in over volumn overall

- ok: a quick indicator of all it fit into bn?

See Also

Other gbp2d: gbp2d_checkr, gbp2d_solver_dpp