Learn R Programming

gbp (version 0.1.0.4)

gbp2d_it_create_ktlist: gbp2d_it_create_ktlist

Description

create ktlist from itlist

Usage

gbp2d_it_create_ktlist(bn, it, xp, ktinit, nlmt)

Arguments

bn
bn scale - l, d bn scale along x and y
it
it position and scale - x, y it position in the bin - l, d it scale along x and y
xp
xp extreme point position and residual space scale - x, y xp position in the bin - l, d xp residual space scale along x and y
ktinit
kt candidate scale without position - l, d kt scale along x and y which open to orientation
nlmt
nlmt: limit on ktlist n max-value

Value

Ktlist2d

Details

core function in gbp2d_solver_dpp select highest profitable it not yet fit into bn and return all possbile fit w.r.t xp and orientation

See Also

Other gbp2d_it: Ktlist2d