Learn R Programming

gbp (version 0.1.0.4)

gbp2d_solver_dpp: gbp2d_solver_dpp

Description

solve gbp2d via extreme point heuristic and best information score fit strategy.

Usage

gbp2d_solver_dpp(p, ld, m)

Arguments

p
p profit of it fit into bn - cluster max(l, d) and min(l, d) via gbp2d_solver_dpp_prep_create_p()
ld
it position and scale - l, d it scale along x and y, subject to orientation rotation
m
bn scale - l, d bn scale along x and y

Value

gbp2d a gbp2d instantiate with p profit, it item (x, y, l, d) position scale matrix, bn bin (l, d) scale vector, k selection, o objective, and ok an indicator of all fit or not.

Details

gbp2d init a profit vector p, a length vector l, a depth vector d, a length constraint ml, and a depth constraint md on l x d rectangle with geometry intepretation.

gbp2d solver would solve

maximize sum_j=1^n p_j k_j

subject to fit (l_j, d_j) at coordinate (x_j, y_j) such that no overlap in ml x md, j = 1, ...., n

and instantiate a gbp2d object with a x-axis coordinate vector x, a y-axis coordinate vector y, a selection vector k, and an objective o.

See Also

Other gbp2d: gbp2d_checkr, gbp2d