gbp3dC++Class of length 1.gbp3d solver would solve
maximize sum_j=1^n p_j k_j
subject to fit (l_j, d_j, h_j) at coordinate (x_j, y_j, z_j) such that no overlap in ml x md x mh cuboid, j = 1, ......, n
and instantiate a gbp3d object with a x-axis coordinate vector x, a y-axis coordinate vector y, a z-axis coordinate vector z, a selection vector k, and an objective o.
a gbp3d class instance has 6 fields:
- p: profit of it fit into bn
created via cluster max(l, d, h) and area via gbp3d_solver_dpp_main_create_p()
- it: it position and scale
- x, y, z it position in the bin
- l, d, h it scale along x, y, z
- bn: bn scale
- l, d, h bn scale along x, y, z
- k: selection indicator 0, 1
- o: objective achivement volumn fit in over volumn overall
- ok: a quick indicator of all it fit into bn?
gbp3d_checkr,
gbp3d_solver_dpp