Learn R Programming

gbp (version 0.1.0.4)

gbp3d_it_create_ktlist: gbp3d_it_create_ktlist

Description

create ktlist from itlist

Usage

gbp3d_it_create_ktlist(bn, it, xp, ktinit, nlmt)

Arguments

bn
bn scale - l, d, h bn scale along x, y, z
it
it position and scale - x, y, z it position in the bin - l, d, h it scale along x, y, z
xp
xp extreme point position and residual space scale - x, y, z xp position in the bin - l, d, h xp residual space scale along x, y, z
ktinit
kt candidate scale without position - l, d, h kt scale along x, y, z which open to orientation
nlmt
nlmt: limit on ktlist n max-value

Value

Ktlist3d

Details

core function in gbp3d_solver_dpp select highest profitable it not yet fit into bn and return all possbile fit w.r.t xp and orientation

See Also

Other gbp3d_it: Ktlist3d