gbp4dC++Class of length 1.maximize sum_j=1^n p_j k_j
subject to sum_j=1^n w_j k_j leq mw and
fit (l_j, d_j, h_j) at coordinate (x_j, y_j, z_j) such that no overlap in ml x md x mh cuboid, j = 1, ......, n
and instantiate a gbp4d object with a x-axis coordinate vector x, a y-axis coordinate vector y, a z-axis coordinate vector z, a selection vector k, and an objective o.
a gbp4d class instance has 6 fields:
- p: profit of it fit into bn
created via cluster w via gbp1d, cluster max(l, d, h) and area via gbp4d_solver_dpp_main_create_p()
- it: it position and scale
- x, y, z, w it position and w in the bin
- l, d, h, w it scale along x, y, z and w
- bn: bn scale
- l, d, h, w bn scale along x, y, z and w
- k: selection indicator 0, 1
- o: objective achivement volumn fit in over volumn overall
- ok: a quick indicator of all it fit into bn?
gbp4d_checkr,
gbp4d_solver_dpp