Learn R Programming

gbp (version 0.1.0.4)

gbp4d_it_create_ktlist: gbp4d_it_create_ktlist

Description

create ktlist from itlist

Usage

gbp4d_it_create_ktlist(bn, it, xp, ktinit, nlmt)

Arguments

bn
bn scale - l, d, h, w bn scale along x, y, z and w
it
it position and scale - x, y, z, w it position and w in the bin - l, d, h, w it scale along x, y, z and w
xp
xp extreme point position and residual space scale - x, y, z, w xp position and w in the bin - l, d, h, w xp residual space scale along x, y, z and w
ktinit
kt candidate scale without position - l, d, h, w kt scale along x, y, z, w which open to orientation
nlmt
nlmt: limit on ktlist n max-value

Value

Ktlist4d

Details

core function in gbp4d_solver_dpp select highest profitable it not yet fit into bn and return all possbile fit w.r.t xp and orientation

See Also

Other gbp4d_it: Ktlist4d