Ktlist2dC++Class of length 1.a Ktlist2d class instance has 4 fields:
- n: length of kt candidate position scale vector list
- kt: candidate (x, y, l, d) fit of it current investigating
- xp: candidate extreme point list after kt fit into each corresponding (x, y, l, d) position scale
- s: score of each kt fit: calculate overall extrem point residual space entropy as score, the smaller the better, since smaller entropy indicate concentrated residual space and less number of extreme point.
gbp2d_it_create_ktlist