bpp_solver_dpp_wrapper(it, bn)it order itemSKU list
- oid: order id
- sku: stock keeping unit - it id
- l, d, h, w it scale along x, y, z and w
- w will be used as constraint while l, d, h will be used as both constraint and objective
it must be sorted w.r.t oid
bn a bin list
- id: bin id
- l, d, h, w bn scale along x, y, z and w
bn must be sorted w.r.t preference and have l >= d >= h
bpp_solver_dpp,
bpp_solver_sgl