bpp_viewer(sn, title = NULL, subtitle = NULL) - it item
- oid: order id
- sku: stock keeping unit as it id
- tid: ticket id - an unique id within oid
- otid: order id x ticket id - an unique indentifier indicate it with same tid can be packed into one bin
- bid: bn id
- x, y, z it position in bid bin
- l, d, h it scale along x, y, z
- w it weight
- bn bins
- id bn id
- l bn length limit along x-coordinate
- d bn depth limit along y-coordinate
- h bn height limit along z-coordinate
- w bn weight limit along w - a separate single dimension
bpp_viewer_single