bpp_viewer_single(it, bn, title = NULL, subtitle = NULL, it_rgl_control = NULL, bn_rgl_control = NULL, label_it = TRUE, label_bn = TRUE) - id it id
- x, y, z it position w.r.t bins
- l, d, h it scale along x, y, z
- w it weight
- auto: cc, wd, txt point and lines color, size, legend
- id bn id
- l, d, h bn scale
- w bn weight limit
- auto: cc, wd, txt point and lines color, size, legend
bpp_viewer