Arguments
bn
bn scale
- l, d, h bn scale along x, y, z
it
it position and scale
- x, y, z it position in the bin
- l, d, h it scale along x, y, z
xp
xp extreme point position and residual space scale
- x, y, z xp position in the bin
- l, d, h xp residual space scale along x, y, z
ktinit
kt candidate scale without position
- l, d, h kt scale along x, y, z which open to orientation
nlmt
nlmt: limit on ktlist n max-value