Rdocumentation
powered by
Learn R Programming
gbp (version 0.1.0.4)
gbp4d_checkr: gbp4d_checkr
Description
auxilium of gbp4d_solver_dpp
Usage
gbp4d_checkr(sn)
Arguments
sn
gbp4d object from gbp4d_solver_dpp() solution.
Value
okfit?
Details
check fit solution is valid: no conflict between item and bin, and no conflict between each pair of item, and no conflict on weight limit.
See Also
Other gbp4d:
gbp4d_solver_dpp
,
gbp4d