Arguments
bn
bn scale
- l, d, h, w bn scale along x, y, z and w
it
it position and scale
- x, y, z, w it position and w in the bin
- l, d, h, w it scale along x, y, z and w
xp
xp extreme point position and residual space scale
- x, y, z, w xp position and w in the bin
- l, d, h, w xp residual space scale along x, y, z and w
ktinit
kt candidate scale without position
- l, d, h, w kt scale along x, y, z, w which open to orientation
nlmt
nlmt: limit on ktlist n max-value