Rdocumentation
powered by
Learn R Programming
gbp (version 0.1.0.4)
gbp4d_solver_dpp_prep_create_p: gbp4d_solver_dpp_prep_create_p
Description
auxilium of gbp4d_solver_dpp
Usage
gbp4d_solver_dpp_prep_create_p(ldhw, m)
Arguments
ldhw
4xN matrix of l, d, h, w of it
m
4x1 vector of l, d, h, w of bn
Value
p
Details
create p via ldhw and m via cluster w, cluster max(l, d, h) and area strategy