Rdocumentation
powered by
Learn R Programming
gbp (version 0.1.0.4)
gbp4q_checkr: gbp4q_checkr
Description
auxilium of gbp4d_solver_dpp_filt
Usage
gbp4q_checkr(sn)
Arguments
sn
gbp4q object from gbp4d_solver_dpp_filt() solution.
Value
okfit?
Details
check fit solution is valid: no conflict between item and bin, and no conflict between each pair of item, and no conflict on weight limit.
See Also
Other gbp4q:
gbp4d_solver_dpp_filt
,
gbp4q